@@ -39,13 +39,11 @@
 # define ATTR_NO_RETRUN __attribute__ ((__noreturn__))
 #endif
 
-ATTR_NO_RETRUN
-static void
+ATTR_NO_RETRUN static void
 usage (int status)
 {
   if (status != EXIT_SUCCESS)
-    fprintf (stderr, "Try `%s --help' for more information.\n",
-	     program_name);
+    fprintf (stderr, "Try `%s --help' for more information.\n", program_name);
   else
     {
       printf ("\
@@ -194,7 +192,7 @@ main (int argc, char *argv[])
 	}
     }
 
-  if (optind == argc || optind == argc -1)
+  if (optind == argc || optind == argc - 1)
     {
       free (outputFileName);
       fprintf (stderr, "asn1Coding: input files missing\n");
